@@ -198,7 +198,7 @@ if re.match(r".+\.csv", fileinput) is not None:
 while True:
     try:
         
-        filename = input("\nType the .csv or .txt of the file to export coordinates:  ")
+        filename = input("\nType the name of the .csv or .txt file to export coordinates:  ")
         
         if re.match(r".+\.csv", fileinput) is not None:
             with open (filename, 'x') as f:
